@@ -24,10 +24,6 @@
 
 concatenate_gui <- function(env=parent.frame(), debug=FALSE){
   
-  # Load dependencies.  
-  require(gWidgets)
-  options(guiToolkit="RGtk2")
-  
   # Global variables.
   .gData1 <- NULL
   .gData2 <- NULL
