@@ -1,9 +1,11 @@
 ################################################################################
 # TODO LIST
-# TODO: .
+# TODO: ...
 
 ################################################################################
 # CHANGE LOG
+# 02.12.2013: Fixed 'Option' frame not visible.
+# 20.11.2013: Specified package for function 'gtable' -> 'gWidgets::gtable'
 # 06.08.2013: Added rows and columns to info.
 # 18.07.2013: Check before overwrite object.
 # 16.07.2013: Added save GUI settings.
@@ -35,10 +37,6 @@
 
 slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
-  # Load dependencies.  
-  require(gWidgets)
-  options(guiToolkit="RGtk2")
-  
   # Global variables.
   .gData <- data.frame(No.Data=NA)
   
@@ -86,25 +84,25 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # DATASET ###################################################################
   
-  frame0 <- gframe(text = "Datasets",
+  f0 <- gframe(text = "Datasets",
                horizontal=FALSE,
                spacing = 5,
                container = g0) 
   
-  g0 <- glayout(container = frame0, spacing = 1)
+  f0g0 <- glayout(container = f0, spacing = 1)
   
-  g0[1,1] <- glabel(text="Select dataset:", container=g0)
+  f0g0[1,1] <- glabel(text="Select dataset:", container=f0g0)
   
-  g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
+  f0g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
                                                  listObjects(env=env,
                                                              objClass="data.frame")),
                                          selected = 1,
                                          editable = FALSE,
-                                         container = g0)
+                                         container = f0g0)
   
-  g0[1,3] <- g0_samples_lbl <- glabel(text=" 0 samples,", container=g0)
-  g0[1,4] <- g0_columns_lbl <- glabel(text=" 0 columns,", container=g0)
-  g0[1,5] <- g0_rows_lbl <- glabel(text=" 0 rows", container=g0)
+  f0g0[1,3] <- f0_samples_lbl <- glabel(text=" 0 samples,", container=f0g0)
+  f0g0[1,4] <- f0_columns_lbl <- glabel(text=" 0 columns,", container=f0g0)
+  f0g0[1,5] <- f0_rows_lbl <- glabel(text=" 0 rows", container=f0g0)
   
   
   addHandlerChanged(dataset_drp, handler = function (h, ...) {
@@ -133,9 +131,9 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         svalue(stack_txt) <- ""
         .refresh_fix_tbl()
         .refresh_stack_tbl()
-        svalue(g0_samples_lbl) <- " 0 samples,"
-        svalue(g0_columns_lbl) <- " 0 columns,"
-        svalue(g0_rows_lbl) <- " 0 rows"
+        svalue(f0_samples_lbl) <- " 0 samples,"
+        svalue(f0_columns_lbl) <- " 0 columns,"
+        svalue(f0_rows_lbl) <- " 0 rows"
         svalue(f2_save_edt) <- ""
         
       } else {
@@ -148,12 +146,12 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         # Info.
         if("Sample.Name" %in% names(.gData)){
           samples <- length(unique(.gData$Sample.Name))
-          svalue(g0_samples_lbl) <- paste(" ", samples, "samples,")
+          svalue(f0_samples_lbl) <- paste(" ", samples, "samples,")
         } else {
-          svalue(g0_samples_lbl) <- paste(" ", "<NA>", "samples,")
+          svalue(f0_samples_lbl) <- paste(" ", "<NA>", "samples,")
         }
-        svalue(g0_columns_lbl) <- paste(" ", ncol(.gData), "columns,")
-        svalue(g0_rows_lbl) <- paste(" ", nrow(.gData), "rows")
+        svalue(f0_columns_lbl) <- paste(" ", ncol(.gData), "columns,")
+        svalue(f0_rows_lbl) <- paste(" ", nrow(.gData), "rows")
         # Result name.
         svalue(f2_save_edt) <- paste(val_obj, "_slim", sep="")
 
@@ -162,6 +160,11 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
         # Guess column names to stack.
         svalue(stack_txt) <- colNames(.gData, slim=FALSE, concatenate="|")
+        
+        # Reset button.
+        svalue(slim_btn) <- "Slim dataset"
+        enabled(slim_btn) <- TRUE
+        
       }
       
     } else {
@@ -172,9 +175,9 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       svalue(stack_txt) <- ""
       .refresh_fix_tbl()
       .refresh_stack_tbl()
-      svalue(g0_samples_lbl) <- paste(" ", "<NA>", "samples,")
-      svalue(g0_columns_lbl) <- paste(" ", "<NA>", "columns,")
-      svalue(g0_rows_lbl) <- paste(" ", "<NA>", "rows")
+      svalue(f0_samples_lbl) <- paste(" ", "<NA>", "samples,")
+      svalue(f0_columns_lbl) <- paste(" ", "<NA>", "columns,")
+      svalue(f0_rows_lbl) <- paste(" ", "<NA>", "rows")
       
       svalue(f2_save_edt) <- ""
       
@@ -198,7 +201,7 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                    width = 40,
                    container=fix_f)
   
-  fix_tbl <- gtable(items=names(.gData), 
+  fix_tbl <- gWidgets::gtable(items=names(.gData), 
                     container=fix_f,
                     expand=TRUE)
   
@@ -247,7 +250,7 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                      width = 40,
                      container=stack_f)
   
-  stack_tbl <- gtable(items=names(.gData),
+  stack_tbl <- gWidgets::gtable(items=names(.gData),
                       container=stack_f,
                       expand=TRUE)
   
@@ -288,6 +291,9 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                         checked=TRUE,
                         container=f1)
   
+  glabel(text=paste("(i.e. keep one row per marker for each sample even if no peak)"),
+         container=f1, anchor=c(-1 ,0))
+  
   glabel(text=paste("\nTip:",
                     "Manually edit the columns to fix and stack.\n",
                     "e.g. 'Allele' will stack 'Allele.1', 'Allele.2'..."),
@@ -347,11 +353,15 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       enabled(slim_btn) <- FALSE
       
       datanew <- slim(data=.gData, fix=fix_val, stack=stack_val,
-                      keepAllFixed=keep_val)
+                      keepAllFixed=keep_val, debug=debug)
       
       # Save data.
       saveObject(name=val_name, object=datanew, parent=w, env=env)
       
+      if(debug){
+        print(paste("EXIT:", match.call()[[1]]))
+      }
+      
       # Close GUI.
       dispose(w)
     
@@ -377,7 +387,7 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     delete(fix_f, fix_tbl)
     
     # ...creating a new table.
-    fix_tbl <<- gtable(items=names(.gData), 
+    fix_tbl <<- gWidgets::gtable(items=names(.gData), 
                            container=fix_f,
                            expand=TRUE)
   
@@ -416,7 +426,7 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     delete(stack_f, stack_tbl)
     
     # ...creating a new table.
-    stack_tbl <<- gtable(items=names(.gData), 
+    stack_tbl <<- gWidgets::gtable(items=names(.gData), 
                        container=stack_f,
                        expand=TRUE)
     
@@ -458,8 +468,8 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       }  
     } else {
       # Load save flag.
-      if(exists(".slim_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".slim_gui_savegui", envir=env)
+      if(exists(".strvalidator_slim_gui_savegui", envir=env, inherits = FALSE)){
+        svalue(f1_savegui_chk) <- get(".strvalidator_slim_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
@@ -471,8 +481,8 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     # Then load settings if true.
     if(svalue(f1_savegui_chk)){
-      if(exists(".slim_gui_title", envir=env, inherits = FALSE)){
-        svalue(f1_keep_chk) <- get(".slim_gui_title", envir=env)
+      if(exists(".strvalidator_slim_gui_title", envir=env, inherits = FALSE)){
+        svalue(f1_keep_chk) <- get(".strvalidator_slim_gui_title", envir=env)
       }
       
       if(debug){
@@ -487,16 +497,16 @@ slim_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     # Then save settings if true.
     if(svalue(f1_savegui_chk)){
       
-      assign(x=".slim_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
-      assign(x=".slim_gui_title", value=svalue(f1_keep_chk), envir=env)
+      assign(x=".strvalidator_slim_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_slim_gui_title", value=svalue(f1_keep_chk), envir=env)
       
     } else { # or remove all saved values if false.
       
-      if(exists(".slim_gui_savegui", envir=env, inherits = FALSE)){
-        remove(".slim_gui_savegui", envir = env)
+      if(exists(".strvalidator_slim_gui_savegui", envir=env, inherits = FALSE)){
+        remove(".strvalidator_slim_gui_savegui", envir = env)
       }
-      if(exists(".slim_gui_title", envir=env, inherits = FALSE)){
-        remove(".slim_gui_title", envir = env)
+      if(exists(".strvalidator_slim_gui_title", envir=env, inherits = FALSE)){
+        remove(".strvalidator_slim_gui_title", envir = env)
       }
       
       if(debug){
